#!/usr/bin/env bash

# Read in variables
source ${BBROOTDIR}/misc/variables.idx

# Read in language
source ${BBROOTDIR}/lang/${BBLANG}/configure.lang

# Read in common functions
source ${BBROOTDIR}/misc/commonfunctions.sh

# Confirmation routine on leaving configuration.
		get_confirm() {
		  echo -e "${bb_conf_xit_2}\n ${bb_conf_err}'n' (${bb_conf_menu0}) ${BBTABLECOLOR}|${BBCOLOROFF} 'y' (${bb_conf_xit_1})"
		  echo -e "${BBDECOLIN3}"
		  while true
		  do
		  echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
		  read ans
			case "$ans" in
			 n | no | No | NO ) # Nick - needs adding lang specific (Nien etc.)
			 return 0;;
			 y | yes | Y | Yes | YES ) # Nick - needs adding lang specific (Ja etc.)
			 return 1;;
			*)  echo -e "${bb_conf_err}y/n" ;; # Lang options?
			esac
		done
		}

# Are you REALLY sure routine for reset to defaults.
		get_really_sure() {
		  echo -e "${bb_conf_menu25}?  ${bb_conf_ch19_5}\n ${bb_conf_err}'n' (${bb_conf_menu0}) ${BBTABLECOLOR}|${BBCOLOROFF} 'y' (${bb_conf_menu25})"
		  echo -e "${BBDECOLIN3}"
		  while true
		  do
		  echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
		  read ans
			case "$ans" in
			 n | no | No | NO ) # Nick - needs adding lang specific (Nien etc.)
			 return 0;;
			 y | yes | Y | Yes | YES ) # Nick - needs adding lang specific (Ja etc.)
			 return 1;;
			*)  return 0;;
			esac
		done
		}

# Confirm new settings.
		get_new_settings() {
		  echo -e "${bb_conf_menu24}?  ${bb_conf_ch19_5}\n ${bb_conf_err}'n' (${bb_conf_menu0}) ${BBTABLECOLOR}|${BBCOLOROFF} 'y' (${bb_conf_menu24})"
		  echo -e "${BBDECOLIN3}"
		  while true
		  do
		  echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
		  read ans
			case "$ans" in
			 n | no | No | NO ) # Nick - needs adding lang specific (Nien etc.)
			 return 0;;
			 y | yes | Y | Yes | YES ) # Nick - needs adding lang specific (Ja etc.)
			 return 1;;
			*)  return 0;;
			esac
		done
		}


### PRINT HEADER ###
pretty_top()
{
	clear
        echo -e "${BBTABLECOLOR}${BBDECOLINE}"
        echo -e "${BBTABLECOLOR}|${BBHEADCOLOR} ${BBVERSION} ${BBTABLECOLOR}|"
        echo -e "${BBTABLECOLOR}${BBDECOLINE}"
        echo -e "${BBTABLECOLOR}|${BBCOLOROFF}"
}

change_writer_device()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_1"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_2"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_3"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_4"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_5${BBMAINCOLOR}/etc/default/cdrecord ${BBOPTIONCOLOR}$bb_conf_ch1_6"
	echo -e "${BBOPTIONCOLOR}$bb_conf_ch1_10"
	echo -e "${BBDECOLIN3}"
	echo -e "${BBMAINCOLOR}$bb_conf_ch1_7${BBCOLOROFF}"
	sleep 2s
	${BB_CDBURNCMD} -scanbus
	echo
	echo -e "${BBMAINCOLOR}$bb_conf_ch1_8${BBCOLOROFF}"
	sleep 2s
	${BB_CDBURNCMD} dev=ATA -scanbus
	echo
	echo -n -e "${BBINPUTCOLOR}$bb_conf_ch1_9${BBCOLOROFF}"
	read BBCDWRITER
	continue 
}

change_cdrom_device()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo -e "${BBMAINCOLOR}"
	echo $bb_conf_ch2_1
	echo
	echo $bb_conf_ch2_2
	echo -e "${BBSUBCOLOR}"
	echo
	grep cdrom /etc/fstab | cut -f 1-2 && grep dvd /etc/fstab | cut -f 1-2 && grep cdrw /etc/fstab | cut -f 1-2
	echo
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}$bb_conf_ch2_3${BBCOLOROFF}"
	read BBCDROM
	continue
}

change_cd_mount_point()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo -e "${BBMAINCOLOR}"
	echo $bb_conf_ch3_1
	echo $bb_conf_ch3_2
	echo -e "${BBSUBCOLOR}"
	echo
	grep cdrom /etc/fstab | cut -f2 && grep dvd /etc/fstab | cut -f2 && grep cdrw /etc/fstab | cut -f2
	echo
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}$bb_conf_ch3_3${BBCOLOROFF}"
	read BBCDMNT
	continue
}

change_writer_speed()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch4_1
	echo $bb_conf_ch4_2
	echo $bb_conf_ch4_3
	echo $bb_conf_ch4_4
	echo $bb_conf_ch4_5
	echo $bb_conf_ch4_6
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}$bb_conf_ch4_7${BBCOLOROFF}"
	read BBSPEED
	continue
}

change_blanking()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	${BB_CDBURNCMD} blank=help
	echo -e "${BBMAINCOLOR}$bb_conf_ch5_1${BBCOLOROFF}"
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBBLANKING}${BBCOLOROFF}"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBBLANKING
	continue
}

set_num_devices()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch6_1
	echo $bb_conf_ch6_2
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBNUMDEV
	continue
}

change_rootdir()
{
	OLDROOTDIR=${BBROOTDIR}
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch7_1
	echo -e "${BBMAINCOLOR}$bb_conf_ch7_2${BBCOLOROFF}"
	echo -e "$bb_conf_ch7_3$bb_conf_ch7_4"
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBROOTDIR}${BBCOLOROFF}"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBROOTDIR
	if [ ${#BBROOTDIR} = 0 ]; then
		BBROOTDIR=${OLDROOTDIR}
	fi
}

change_burndir()
{
	OLDBURNDIR=${BBBURNDIR}
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch8_1
	echo $bb_conf_ch8_2
	echo -e "$bb_conf_ch7_3$bb_conf_ch7_4"
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBBURNDIR}${BBCOLOROFF}"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBBURNDIR
	if [ ${#BBBURNDIR} = 0 ]; then
		BBBURNDIR=${OLDBURNDIR}
	fi
}

change_label()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch9_1
	echo $bb_conf_ch9_2
	echo $bb_conf_ch9_3
	echo -e "$bb_conf_ch9_4${BBOPTIONCOLOR}${BBLABEL}${BBCOLOROFF}." 
	echo $bb_conf_ch9_4b
	echo $bb_conf_ch9_4c
	echo $bb_conf_ch9_5
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBLABEL
}

change_copyright_cd()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch10_1
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBCOPYRIGHT}${BBCOLOROFF}"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBCOPYRIGHT
}

set_author()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch11_1
	echo $bb_conf_ch11_2
	echo $bb_conf_ch11_3
	echo -e "$bb_conf_ch11_4${BBOPTIONCOLOR}${BBAUTHOR}${BBCOLOROFF}"
	echo $bb_conf_ch11_5
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBAUTHOR
}

set_publisher()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch12_1
	echo $bb_conf_ch12_2
	echo $bb_conf_ch12_3
	echo -e "$bb_conf_ch12_4${BBOPTIONCOLOR}${BBPUBLISHER}${BBCOLOROFF}."
	echo $bb_conf_ch12_5
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBPUBLISHER
}

set_description()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch13_1
	echo $bb_conf_ch13_2
	echo $bb_conf_ch13_3
	echo -e "${BBOPTIONCOLOR}${BBDESCRIPTION}${BBCOLOROFF}"
	echo $bb_conf_ch13_4
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBDESCRIPTION
}

set_package_name()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch14_1
	echo $bb_conf_ch14_2
	echo $bb_conf_ch14_3
	echo $bb_conf_ch14_4
	echo -e "$bb_conf_ch14_5${BBOPTIONCOLOR}${BBNAMEOFPACKAGE}${BBCOLOROFF}"
	echo $bb_conf_ch14_6
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBNAMEOFPACKAGE
}

set_normalize()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch15_1
	echo $bb_conf_ch15_2
	echo $bb_conf_ch15_3
	echo -e "$bb_conf_ch15_4${BBOPTIONCOLOR}${BBNORMALIZE}${BBCOLOROFF}."
	echo $bb_conf_ch15_5
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBNORMALIZE
}

set_driver_options()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch16_1
	echo $bb_conf_ch16_2
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}<${BBOPT_ONE}>${BBCOLOROFF}"
	${BB_CDBURNCMD} dev=$BBCDWRITER -checkdrive driveropts=help 
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBOPT_ONE
}

set_fifo_dir()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch17_1
	echo $bb_conf_ch17_2
	echo -e "$bb_conf_ch17_3${BBOPTIONCOLOR}${BBFIFODIR}${BBCOLOROFF}$bb_conf_ch17_4"
	echo -e "(${BBOPTIONCOLOR}${BBFIFODIR}${BBCOLOROFF}$bb_conf_ch17_5"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBFIFODIR
}

delete_temp()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo -e "$bb_conf_ch18_1${BBOPTIONCOLOR}${BBBURNDIR}${BBCOLOROFF}$bb_conf_ch18_2"
	echo $bb_conf_ch18_3
	echo $bb_conf_ch18_4
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBDELTEMPBURN}${BBCOLOROFF}."
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBDELTEMPBURN
}

set_overburn()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch19_1
	echo $bb_conf_ch19_2
	echo $bb_conf_ch19_3
	echo $bb_conf_ch19_4
	echo $bb_conf_ch19_5
	echo -e "$bb_conf_ch5_2${BBOPTIONCOLOR}${BBOVERBURN}${BBCOLOROFF}."
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBOVERBURN
}

set_audio_copyprotect()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch20_1
	echo -e "$bb_conf_ch20_2$bb_conf_ch5_2${BBOPTIONCOLOR}${BBCOPY_PROTECT}${BBCOLOROFF}"
	echo -e "${BBMAINCOLOR}$bb_conf_ch20_3${BBCOLOROFF}$bb_conf_ch20_4${BBMAINCOLOR}$bb_conf_ch20_5${BBCOLOROFF}$bb_conf_ch20_6"
	echo $bb_conf_ch20_7
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBCOPY_PROTECT
}

set_bitrate()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch21_1
	echo $bb_conf_ch21_2
	echo $bb_conf_ch21_3
	echo $bb_conf_ch21_4
	echo "ie. 64, 128, 160, 192, 256."
	echo -e "$bb_conf_ch21_5$bb_conf_ch5_2${BBOPTIONCOLOR}${BBBITRATE}${BBCOLOROFF}"
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBBITRATE
}

set_language()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch22_1
	echo $bb_conf_ch22_2; echo
	ls ${BBROOTDIR}/lang
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBLANG
}

set_dtao()
{
	pretty_top
	echo -e "${BBINFOLINE}"
	echo $bb_conf_ch23_1
	echo -e ${BBOPTIONCOLOR}$bb_conf_ch23_2${BBCOLOROFF}$bb_conf_ch23_2b${BBOPTIONCOLOR}$bb_conf_ch23_2c${BBCOLOROFF}
	echo $bb_conf_ch23_3
	echo -e ${BBOPTIONCOLOR}$bb_conf_ch23_4${BBCOLOROFF}$bb_conf_ch23_5
	echo $bb_conf_ch23_6
	echo $bb_conf_ch23_7
	echo -e "${BBDECOLIN3}"
	echo
	echo -n -e "${BBINPUTCOLOR}|> ${BBCOLOROFF}"
	read BBDTAO
}


#####PROGRAM START#####
while true; do
	# <colors>
	#source "$BBROOTDIR"/misc/colors.idx
	# </colors>
	# Top and bottom lines for Information
	BBINFOLINE="${BBTABLECOLOR}${BBDECOLINE}${BBSUBCOLOR} INFORMATION ${BBTABLECOLOR}${BBDECOLINE}${BBCOLOROFF}"
	BBDECOLIN3="${BBTABLECOLOR}${BBDECOLINE}-------------${BBDECOLINE}${BBCOLOROFF}"
	# <table>
	pretty_top
	echo -e "${BBTABLECOLOR}|-(${BBSUBCOLOR}Setup${BBTABLECOLOR})\t\t\t${BBTABLECOLOR}(${BBSUBCOLOR}CURRENT VALUE${BBTABLECOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  1) $bb_conf_menu1(${BBOPTIONCOLOR}$BBCDWRITER${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  2) $bb_conf_menu2(${BBOPTIONCOLOR}$BBCDROM${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  3) $bb_conf_menu3(${BBOPTIONCOLOR}$BBCDMNT${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  4) $bb_conf_menu4(${BBOPTIONCOLOR}$BBSPEED${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  5) $bb_conf_menu5(${BBOPTIONCOLOR}$BBBLANKING${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  6) $bb_conf_menu6(${BBOPTIONCOLOR}$BBNUMDEV${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  7) $bb_conf_menu7(${BBOPTIONCOLOR}$BBROOTDIR${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  8) $bb_conf_menu8(${BBOPTIONCOLOR}$BBBURNDIR${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR}  9) $bb_conf_menu9(${BBOPTIONCOLOR}$BBLABEL${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 10) $bb_conf_menu10(${BBOPTIONCOLOR}$BBCOPYRIGHT${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 11) $bb_conf_menu11(${BBOPTIONCOLOR}$BBAUTHOR${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 12) $bb_conf_menu12(${BBOPTIONCOLOR}$BBPUBLISHER${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 13) $bb_conf_menu13(${BBOPTIONCOLOR}$BBDESCRIPTION${BBMAINCOLOR})" 
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 14) $bb_conf_menu14(${BBOPTIONCOLOR}$BBNAMEOFPACKAGE${BBMAINCOLOR})" 
	
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 15) $bb_conf_menu15(${BBOPTIONCOLOR}$BBNORMALIZE${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 16) $bb_conf_menu16(${BBOPTIONCOLOR}$BBOPT_ONE${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 17) $bb_conf_menu17(${BBOPTIONCOLOR}$BBFIFODIR${BBMAINCOLOR})"	
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 18) $bb_conf_menu18(${BBOPTIONCOLOR}$BBDELTEMPBURN${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 19) $bb_conf_menu19(${BBOPTIONCOLOR}$BBOVERBURN${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 20) $bb_conf_menu20(${BBOPTIONCOLOR}$BBCOPY_PROTECT${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 21) $bb_conf_menu21(${BBOPTIONCOLOR}$BBBITRATE${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 22) $bb_conf_menu22(${BBOPTIONCOLOR}$BBLANG${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|${BBMAINCOLOR} 23) $bb_conf_menu23(${BBOPTIONCOLOR}$BBDTAO${BBMAINCOLOR})"
	echo -e "${BBTABLECOLOR}|"
	echo -e "${BBTABLECOLOR}|-(${BBSUBCOLOR}Actions${BBTABLECOLOR})"
        echo -e "${BBTABLECOLOR}  |-  #${BBMAINCOLOR}24) $bb_conf_menu24 ${BBTABLECOLOR}#${BBMAINCOLOR}25) $bb_conf_menu25 ${BBTABLECOLOR}#${BBMAINCOLOR}0) $bb_conf_menu0"
	echo -e ""

	echo -n -e "${BBINPUTCOLOR}$bb_conf_menu_entry |>${BBMAINCOLOR} "
	read action
	echo -e "${BBCOLOROFF}"
	# </table>

	case $action in
  		1)	#Change writer device
			change_writer_device
		;;	
		2)	#Change cdrom device file
			change_cdrom_device
		;;
		3)	#Change cdrom mount point
			change_cd_mount_point
		;;
		4)	#Change writer speed
			change_writer_speed
		;;
		5)	#Change type of blanking
			change_blanking
		;;
		6)	#Number of devices
			set_num_devices
		;;
		7)	#Change of ROOTDIR. Be careful!
			change_rootdir
		;;
		8)	#Change of BBBURNDIR. Default usually ok.
			change_burndir
		;;			
		9)	#Label of the cd
			change_label
		;;					
		10)	#Copyright notice (If any)
			change_copyright_cd
		;;
		11)	#Author
			set_author
		;;
		12)	#Publisher
			set_publisher
		;;
		13)	#Content description
			set_description
		;;
		14)	#Name of package
			set_package_name
		;;
		15)	#Use normalize
			set_normalize
		;;
		16)	#Driver options
			set_driver_options
		;;
		17)	#FIFO dir for direct audio burning
			set_fifo_dir
		;;
		18)	# Delete tempdir?
			delete_temp
		;;
		19)	#Overburn
			set_overburn
		;;
		20)	#Audio set Copy Protection 
			set_audio_copyprotect
		;;
		21)	#BITRATE OPTION
			set_bitrate
		;;
		22)	#Language Option
			set_language
		;;
		23)	#DAO/TAO
			set_dtao
		;;
		24)	#Apply changes
			pretty_top
                        echo -e "${BBINFOLINE}"
                        if get_new_settings ; then
                        continue
                        fi
			${BBROOTDIR}/config/apply_options.sh
			source ${BBROOTDIR}/misc/variables.idx
		;;
		25)	#Apply default values
                        pretty_top
                        echo -e "${BBINFOLINE}"
			if get_really_sure ; then
                        continue
                        fi
			${BBROOTDIR}/config/reset_options.sh
			source ${BBROOTDIR}/misc/variables.idx
		;;
  		0)	#Back to main menu
			pretty_top
                        echo -e "${BBINFOLINE}"
			if get_confirm ; then 
			continue
			fi
   			echo $bb_conf_xit_1
			sleep 1s
  			break
		;;
  		*)	#You did a bad bad thing
			pretty_top
		        echo -e "${BBINFOLINE}"
			echo
   			echo -e "     ${BBMAINCOLOR}$bb_conf_err 0 - 26${BBCOLOROFF}"
			echo
			echo -e "${BBDECOLIN3}"
			wait_for_enter
			continue
  		;;
 	esac
done
